@@ -1,9 +1,10 @@
 package Business::CCCheck;
 
+use 5.006;
 use strict;
 use warnings;
 
-our $VERSION = '0.05_01';
+our $VERSION = '0.06';
 
 use Business::CCCheck::CardID;
 
@@ -297,8 +298,6 @@ Performs a strict LUHN check on a credit card number,
 and returns true if the number has a valid check digit,
 false otherwise.
 
-=back
-
 =cut
 
 # generic id of credit card number
@@ -455,25 +454,7 @@ Validation criteria are:
 	JCB		3		   16	   mod 10
 	JCB		2131, 1800	   15	   mod 10
 
-=item EXPORT_OK
-
-	@CC_months
-	CC_clean
-	CC_digits
-	CC_oldtype
-	CC_parity
-	CC_typGeneric
-	CC_typDetail
-	CC_format
-	CC_year
-	CC_gen_date
-	CC_is_name
-	CC_is_addr
-	CC_is_zip
-	CC_expired
-
-
-=head1 COPYRIGHT
+=head1 COPYRIGHT AND LICENSE
 
 Copyright 2001 - 2011, Michael Robinton E<lt>michael@bizsystems.comE<gt>
 
